## 0.10.0.7 (2023-03-09)

`parsimonious`: Update return types of `NodeVisitor`'s methods (#9564)

## 0.10.0.6 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 0.10.0.5 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 0.10.0.4 (2023-02-07)

Enable flake8-pyi's Y037 (#9686)

## 0.10.0.3 (2023-02-07)

Bump mypy to 1.0 (#9684)

## 0.10.0.2 (2023-02-02)

Manual changes of `Any` union to `Incomplete` in stubs folder (#9566)

- ClassVar[Any | None]
- Missed previous changes due to alias
- Manual review of leftover Any unions (`| Any` and `Any |`)

## 0.10.0.1 (2022-10-20)

Mark `parsimonious` as completed (#8934)

## 0.10.0 (2022-09-13)

Update parsimonious to 0.10.0 (#8730)

## 0.9.1 (2022-07-12)

Import `Match` and `Pattern` from `re`, not `typing` (#8277)

## 0.9.0 (2022-06-21)

Bump parsimonious to 0.9.* (#8117)

## 0.8.5 (2022-05-07)

Import generics from standard modules in all third-party stubs (#7791)

## 0.8.4 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 0.8.3 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 0.8.2 (2022-03-19)

Add mypy error codes to `type: ignore`s, remove unused ignores (#7504)

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 0.8.1 (2022-03-13)

parsimonious: `re.Match` does not exist in Python 3.6 (#7482)

It has to be imported from `typing` in <3.7.
Refs https://github.com/python/typeshed/pull/7478.

## 0.8.0 (2022-03-13)

Stubs for parsimonious (#7477)

